""" NewBuiltins - Provides and installs addons for Python from the C
                  extension package mxTools.

    (c) Copyright Marc-Andre Lemburg; All Rights Reserved.
    See the documentation for further information on copyrights,
    or contact the author (mal@lemburg.com).
"""
__package_info__ = """
BEGIN PYTHON-PACKAGE-INFO 1.0
Current-Version:	1.0.0
Title:          	mxTools - A collection of new builtins for Python
Home-page:      	http://starship.skyport.net/crew/lemburg/mxTools.html
Primary-site:		http://startship.skyport.net/crew/lemburg/mxTools-1.0.0.zip

The package contains a collection of useful functions that aid in
common tasks like iterating over objects or applying functions to
sets of parameters. The functions contained in the package auto-install
themselves as builtins when the package is imported.

You should visit the home page every now and then for updates, since
the package will eventually evolve with time.

END PYTHON-PACKAGE-INFO
"""
from NewBuiltins import *
from NewBuiltins import __version__
